@@ -17,6 +17,7 @@ import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
 from google.api_core import gapic_v1  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
@@ -147,10 +148,14 @@ class ForwardingRulesRestTransport(ForwardingRulesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.get(url, headers=headers,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.ForwardingRuleAggregatedList.from_json(
@@ -229,10 +234,14 @@ class ForwardingRulesRestTransport(ForwardingRulesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.delete(url, headers=headers,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
@@ -301,10 +310,14 @@ class ForwardingRulesRestTransport(ForwardingRulesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.get(url, headers=headers,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.ForwardingRule.from_json(
@@ -387,10 +400,14 @@ class ForwardingRulesRestTransport(ForwardingRulesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, data=body,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.post(url, headers=headers, data=body,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
@@ -446,10 +463,14 @@ class ForwardingRulesRestTransport(ForwardingRulesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.get(url, headers=headers,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.ForwardingRuleList.from_json(
@@ -535,10 +556,105 @@ class ForwardingRulesRestTransport(ForwardingRulesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.patch(url, data=body,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.patch(url, headers=headers, data=body,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
+
+        # Return the response
+        return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
+
+    def set_labels(
+        self,
+        request: compute.SetLabelsForwardingRuleRequest,
+        *,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> compute.Operation:
+        r"""Call the set labels method over HTTP.
+
+        Args:
+            request (~.compute.SetLabelsForwardingRuleRequest):
+                The request object. A request message for
+                ForwardingRules.SetLabels. See the
+                method description for details.
+
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            ~.compute.Operation:
+                Represents an Operation resource.
+
+                Google Compute Engine has three Operation resources:
+
+                -  `Global </compute/docs/reference/rest/{$api_version}/globalOperations>`__
+                   \*
+                   `Regional </compute/docs/reference/rest/{$api_version}/regionOperations>`__
+                   \*
+                   `Zonal </compute/docs/reference/rest/{$api_version}/zoneOperations>`__
+
+                You can use an operation resource to manage asynchronous
+                API requests. For more information, read Handling API
+                responses.
+
+                Operations can be global, regional or zonal.
+
+                -  For global operations, use the ``globalOperations``
+                   resource.
+                -  For regional operations, use the ``regionOperations``
+                   resource.
+                -  For zonal operations, use the ``zonalOperations``
+                   resource.
+
+                For more information, read Global, Regional, and Zonal
+                Resources. (== resource_for
+                {$api_version}.globalOperations ==) (== resource_for
+                {$api_version}.regionOperations ==) (== resource_for
+                {$api_version}.zoneOperations ==)
+
+        """
+
+        # Jsonify the request body
+        body = compute.RegionSetLabelsRequest.to_json(
+            request.region_set_labels_request_resource,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
+        )
+
+        # TODO(yon-mg): need to handle grpc transcoding and parse url correctly
+        #               current impl assumes basic case of grpc transcoding
+        url = "https://{host}/compute/v1/projects/{project}/regions/{region}/forwardingRules/{resource}/setLabels".format(
+            host=self._host,
+            project=request.project,
+            region=request.region,
+            resource=request.resource,
+        )
+
+        # TODO(yon-mg): handle nested fields corerctly rather than using only top level fields
+        #               not required for GCE
+        query_params = {}
+        if compute.SetLabelsForwardingRuleRequest.request_id in request:
+            query_params["requestId"] = request.request_id
+
+        # TODO(yon-mg): further discussion needed whether 'python truthiness' is appropriate here
+        #               discards default values
+        # TODO(yon-mg): add test for proper url encoded strings
+        query_params = ["{k}={v}".format(k=k, v=v) for k, v in query_params.items()]
+        url += "?{}".format("&".join(query_params)).replace(" ", "+")
+
+        # Send the request
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.post(url, headers=headers, data=body,)
+
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
@@ -622,10 +738,14 @@ class ForwardingRulesRestTransport(ForwardingRulesTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, data=body,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.post(url, headers=headers, data=body,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
