@@ -52,7 +52,7 @@ class TargetHttpsProxiesClientMeta(type):
     def get_transport_class(
         cls, label: str = None,
     ) -> Type[TargetHttpsProxiesTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -75,7 +75,8 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -109,7 +110,8 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -126,7 +128,7 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -145,16 +147,17 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
 
     @property
     def transport(self) -> TargetHttpsProxiesTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            TargetHttpsProxiesTransport: The transport used by the client instance.
+            TargetHttpsProxiesTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -167,7 +170,7 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -178,7 +181,7 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -189,7 +192,7 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -200,7 +203,7 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -219,7 +222,7 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the target https proxies client.
+        """Instantiates the target https proxies client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -274,9 +277,10 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -288,12 +292,14 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -308,8 +314,8 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -762,6 +768,116 @@ class TargetHttpsProxiesClient(metaclass=TargetHttpsProxiesClientMeta):
         # Done; return the response.
         return response
 
+    def patch(
+        self,
+        request: compute.PatchTargetHttpsProxyRequest = None,
+        *,
+        project: str = None,
+        target_https_proxy: str = None,
+        target_https_proxy_resource: compute.TargetHttpsProxy = None,
+        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> compute.Operation:
+        r"""Patches the specified TargetHttpsProxy resource with the data
+        included in the request. This method supports PATCH semantics
+        and uses JSON merge patch format and processing rules. (==
+        suppress_warning http-rest-shadowed ==)
+
+        Args:
+            request (google.cloud.compute_v1.types.PatchTargetHttpsProxyRequest):
+                The request object. A request message for
+                TargetHttpsProxies.Patch. See the method description for
+                details.
+            project (str):
+                Project ID for this request.
+                This corresponds to the ``project`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            target_https_proxy (str):
+                Name of the TargetHttpsProxy resource
+                to patch.
+
+                This corresponds to the ``target_https_proxy`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            target_https_proxy_resource (google.cloud.compute_v1.types.TargetHttpsProxy):
+                The body resource for this request
+                This corresponds to the ``target_https_proxy_resource`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.compute_v1.types.Operation:
+                Represents an Operation resource.
+
+                   Google Compute Engine has three Operation resources:
+
+                   -  [Global](/compute/docs/reference/rest/{$api_version}/globalOperations)
+                      \*
+                      [Regional](/compute/docs/reference/rest/{$api_version}/regionOperations)
+                      \*
+                      [Zonal](/compute/docs/reference/rest/{$api_version}/zoneOperations)
+
+                   You can use an operation resource to manage
+                   asynchronous API requests. For more information, read
+                   Handling API responses.
+
+                   Operations can be global, regional or zonal. - For
+                   global operations, use the globalOperations resource.
+                   - For regional operations, use the regionOperations
+                   resource. - For zonal operations, use the
+                   zonalOperations resource.
+
+                   For more information, read Global, Regional, and
+                   Zonal Resources. (== resource_for
+                   {$api_version}.globalOperations ==) (== resource_for
+                   {$api_version}.regionOperations ==) (== resource_for
+                   {$api_version}.zoneOperations ==)
+
+        """
+        # Create or coerce a protobuf request object.
+        # Sanity check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any(
+            [project, target_https_proxy, target_https_proxy_resource]
+        )
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a compute.PatchTargetHttpsProxyRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, compute.PatchTargetHttpsProxyRequest):
+            request = compute.PatchTargetHttpsProxyRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if project is not None:
+                request.project = project
+            if target_https_proxy is not None:
+                request.target_https_proxy = target_https_proxy
+            if target_https_proxy_resource is not None:
+                request.target_https_proxy_resource = target_https_proxy_resource
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.patch]
+
+        # Send the request.
+        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
     def set_quic_override(
         self,
         request: compute.SetQuicOverrideTargetHttpsProxyRequest = None,
