@@ -17,6 +17,7 @@ import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple
 
 from google.api_core import gapic_v1  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
@@ -144,10 +145,14 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.get(url, headers=headers,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.VpnGatewayAggregatedList.from_json(
@@ -226,10 +231,14 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.delete(url,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.delete(url, headers=headers,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
@@ -285,10 +294,14 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.get(url, headers=headers,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.VpnGateway.from_json(
@@ -337,10 +350,14 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.get(url, headers=headers,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.VpnGatewaysGetStatusResponse.from_json(
@@ -423,10 +440,14 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, data=body,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.post(url, headers=headers, data=body,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
@@ -482,10 +503,14 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.get(url,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.get(url, headers=headers,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.VpnGatewayList.from_json(
@@ -571,10 +596,14 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, data=body,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.post(url, headers=headers, data=body,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.Operation.from_json(response.content, ignore_unknown_fields=True)
@@ -628,10 +657,14 @@ class VpnGatewaysRestTransport(VpnGatewaysTransport):
         url += "?{}".format("&".join(query_params)).replace(" ", "+")
 
         # Send the request
-        response = self._session.post(url, data=body,)
+        headers = dict(metadata)
+        headers["Content-Type"] = "application/json"
+        response = self._session.post(url, headers=headers, data=body,)
 
-        # Raise requests.exceptions.HTTPError if the status code is >= 400
-        response.raise_for_status()
+        # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+        # subclass.
+        if response.status_code >= 400:
+            raise core_exceptions.from_http_response(response)
 
         # Return the response
         return compute.TestPermissionsResponse.from_json(
