@@ -24,6 +24,7 @@ from .compute import (
     AcceleratorTypesScopedList,
     AccessConfig,
     AddAccessConfigInstanceRequest,
+    AddAssociationFirewallPolicyRequest,
     AddHealthCheckTargetPoolRequest,
     AddInstancesInstanceGroupRequest,
     AddInstanceTargetPoolRequest,
@@ -36,9 +37,11 @@ from .compute import (
     AddressAggregatedList,
     AddressesScopedList,
     AddressList,
+    AddRuleFirewallPolicyRequest,
     AddRuleSecurityPolicyRequest,
     AddSignedUrlKeyBackendBucketRequest,
     AddSignedUrlKeyBackendServiceRequest,
+    AdvancedMachineFeatures,
     AggregatedListAcceleratorTypesRequest,
     AggregatedListAddressesRequest,
     AggregatedListAutoscalersRequest,
@@ -58,6 +61,7 @@ from .compute import (
     AggregatedListNodeTemplatesRequest,
     AggregatedListNodeTypesRequest,
     AggregatedListPacketMirroringsRequest,
+    AggregatedListPublicDelegatedPrefixesRequest,
     AggregatedListRegionCommitmentsRequest,
     AggregatedListReservationsRequest,
     AggregatedListResourcePoliciesRequest,
@@ -97,13 +101,18 @@ from .compute import (
     AutoscalingPolicyCustomMetricUtilization,
     AutoscalingPolicyLoadBalancingUtilization,
     AutoscalingPolicyScaleInControl,
+    AutoscalingPolicyScalingSchedule,
     Backend,
     BackendBucket,
     BackendBucketCdnPolicy,
+    BackendBucketCdnPolicyBypassCacheOnRequestHeader,
+    BackendBucketCdnPolicyNegativeCachingPolicy,
     BackendBucketList,
     BackendService,
     BackendServiceAggregatedList,
     BackendServiceCdnPolicy,
+    BackendServiceCdnPolicyBypassCacheOnRequestHeader,
+    BackendServiceCdnPolicyNegativeCachingPolicy,
     BackendServiceFailoverPolicy,
     BackendServiceGroupHealth,
     BackendServiceIAP,
@@ -112,9 +121,14 @@ from .compute import (
     BackendServiceReference,
     BackendServicesScopedList,
     Binding,
+    BulkInsertInstanceRequest,
+    BulkInsertInstanceResource,
+    BulkInsertInstanceResourcePerInstanceProperties,
+    BulkInsertRegionInstanceRequest,
     CacheInvalidationRule,
     CacheKeyPolicy,
     CircuitBreakers,
+    CloneRulesFirewallPolicyRequest,
     Commitment,
     CommitmentAggregatedList,
     CommitmentList,
@@ -139,6 +153,7 @@ from .compute import (
     DeleteBackendServiceRequest,
     DeleteDiskRequest,
     DeleteExternalVpnGatewayRequest,
+    DeleteFirewallPolicyRequest,
     DeleteFirewallRequest,
     DeleteForwardingRuleRequest,
     DeleteGlobalAddressRequest,
@@ -148,6 +163,7 @@ from .compute import (
     DeleteGlobalOperationResponse,
     DeleteGlobalOrganizationOperationRequest,
     DeleteGlobalOrganizationOperationResponse,
+    DeleteGlobalPublicDelegatedPrefixeRequest,
     DeleteHealthCheckRequest,
     DeleteImageRequest,
     DeleteInstanceGroupManagerRequest,
@@ -167,6 +183,8 @@ from .compute import (
     DeletePacketMirroringRequest,
     DeletePerInstanceConfigsInstanceGroupManagerRequest,
     DeletePerInstanceConfigsRegionInstanceGroupManagerRequest,
+    DeletePublicAdvertisedPrefixeRequest,
+    DeletePublicDelegatedPrefixeRequest,
     DeleteRegionAutoscalerRequest,
     DeleteRegionBackendServiceRequest,
     DeleteRegionDiskRequest,
@@ -245,21 +263,33 @@ from .compute import (
     Firewall,
     FirewallList,
     FirewallLogConfig,
+    FirewallPoliciesListAssociationsResponse,
+    FirewallPolicy,
+    FirewallPolicyAssociation,
+    FirewallPolicyList,
+    FirewallPolicyRule,
+    FirewallPolicyRuleMatcher,
+    FirewallPolicyRuleMatcherLayer4Config,
     FixedOrPercent,
     ForwardingRule,
     ForwardingRuleAggregatedList,
     ForwardingRuleList,
     ForwardingRuleReference,
+    ForwardingRuleServiceDirectoryRegistration,
     ForwardingRulesScopedList,
     GetAcceleratorTypeRequest,
     GetAddressRequest,
+    GetAssociationFirewallPolicyRequest,
     GetAutoscalerRequest,
     GetBackendBucketRequest,
     GetBackendServiceRequest,
     GetDiagnosticsInterconnectRequest,
     GetDiskRequest,
     GetDiskTypeRequest,
+    GetEffectiveFirewallsInstanceRequest,
+    GetEffectiveFirewallsNetworkRequest,
     GetExternalVpnGatewayRequest,
+    GetFirewallPolicyRequest,
     GetFirewallRequest,
     GetForwardingRuleRequest,
     GetFromFamilyImageRequest,
@@ -268,12 +298,14 @@ from .compute import (
     GetGlobalNetworkEndpointGroupRequest,
     GetGlobalOperationRequest,
     GetGlobalOrganizationOperationRequest,
+    GetGlobalPublicDelegatedPrefixeRequest,
     GetGuestAttributesInstanceRequest,
     GetHealthBackendServiceRequest,
     GetHealthCheckRequest,
     GetHealthRegionBackendServiceRequest,
     GetHealthTargetPoolRequest,
     GetIamPolicyDiskRequest,
+    GetIamPolicyFirewallPolicyRequest,
     GetIamPolicyImageRequest,
     GetIamPolicyInstanceRequest,
     GetIamPolicyInstanceTemplateRequest,
@@ -304,6 +336,8 @@ from .compute import (
     GetNodeTypeRequest,
     GetPacketMirroringRequest,
     GetProjectRequest,
+    GetPublicAdvertisedPrefixeRequest,
+    GetPublicDelegatedPrefixeRequest,
     GetRegionAutoscalerRequest,
     GetRegionBackendServiceRequest,
     GetRegionCommitmentRequest,
@@ -326,6 +360,7 @@ from .compute import (
     GetRouteRequest,
     GetRouterRequest,
     GetRouterStatusRouterRequest,
+    GetRuleFirewallPolicyRequest,
     GetRuleSecurityPolicyRequest,
     GetScreenshotInstanceRequest,
     GetSecurityPolicyRequest,
@@ -353,6 +388,7 @@ from .compute import (
     GetZoneRequest,
     GlobalNetworkEndpointGroupsAttachEndpointsRequest,
     GlobalNetworkEndpointGroupsDetachEndpointsRequest,
+    GlobalOrganizationSetPolicyRequest,
     GlobalSetLabelsRequest,
     GlobalSetPolicyRequest,
     GRPCHealthCheck,
@@ -396,11 +432,13 @@ from .compute import (
     InsertBackendServiceRequest,
     InsertDiskRequest,
     InsertExternalVpnGatewayRequest,
+    InsertFirewallPolicyRequest,
     InsertFirewallRequest,
     InsertForwardingRuleRequest,
     InsertGlobalAddressRequest,
     InsertGlobalForwardingRuleRequest,
     InsertGlobalNetworkEndpointGroupRequest,
+    InsertGlobalPublicDelegatedPrefixeRequest,
     InsertHealthCheckRequest,
     InsertImageRequest,
     InsertInstanceGroupManagerRequest,
@@ -415,6 +453,8 @@ from .compute import (
     InsertNodeGroupRequest,
     InsertNodeTemplateRequest,
     InsertPacketMirroringRequest,
+    InsertPublicAdvertisedPrefixeRequest,
+    InsertPublicDelegatedPrefixeRequest,
     InsertRegionAutoscalerRequest,
     InsertRegionBackendServiceRequest,
     InsertRegionCommitmentRequest,
@@ -492,6 +532,8 @@ from .compute import (
     InstanceProperties,
     InstanceReference,
     InstancesAddResourcePoliciesRequest,
+    InstancesGetEffectiveFirewallsResponse,
+    InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy,
     InstancesRemoveResourcePoliciesRequest,
     InstancesScopedList,
     InstancesSetLabelsRequest,
@@ -533,6 +575,7 @@ from .compute import (
     LicensesListResponse,
     ListAcceleratorTypesRequest,
     ListAddressesRequest,
+    ListAssociationsFirewallPolicyRequest,
     ListAutoscalersRequest,
     ListAvailableFeaturesSslPoliciesRequest,
     ListBackendBucketsRequest,
@@ -542,6 +585,7 @@ from .compute import (
     ListErrorsInstanceGroupManagersRequest,
     ListErrorsRegionInstanceGroupManagersRequest,
     ListExternalVpnGatewaysRequest,
+    ListFirewallPoliciesRequest,
     ListFirewallsRequest,
     ListForwardingRulesRequest,
     ListGlobalAddressesRequest,
@@ -549,6 +593,7 @@ from .compute import (
     ListGlobalNetworkEndpointGroupsRequest,
     ListGlobalOperationsRequest,
     ListGlobalOrganizationOperationsRequest,
+    ListGlobalPublicDelegatedPrefixesRequest,
     ListHealthChecksRequest,
     ListImagesRequest,
     ListInstanceGroupManagersRequest,
@@ -577,6 +622,8 @@ from .compute import (
     ListPerInstanceConfigsInstanceGroupManagersRequest,
     ListPerInstanceConfigsRegionInstanceGroupManagersRequest,
     ListPreconfiguredExpressionSetsSecurityPoliciesRequest,
+    ListPublicAdvertisedPrefixesRequest,
+    ListPublicDelegatedPrefixesRequest,
     ListReferrersInstancesRequest,
     ListRegionAutoscalersRequest,
     ListRegionBackendServicesRequest,
@@ -620,6 +667,8 @@ from .compute import (
     ListZoneOperationsRequest,
     ListZonesRequest,
     LocalDisk,
+    LocationPolicy,
+    LocationPolicyLocation,
     LogConfig,
     LogConfigCloudAuditOptions,
     LogConfigCounterOptions,
@@ -637,6 +686,7 @@ from .compute import (
     MetadataFilter,
     MetadataFilterLabelMatch,
     MoveDiskProjectRequest,
+    MoveFirewallPolicyRequest,
     MoveInstanceProjectRequest,
     NamedPort,
     Network,
@@ -658,6 +708,8 @@ from .compute import (
     NetworkPeering,
     NetworkRoutingConfig,
     NetworksAddPeeringRequest,
+    NetworksGetEffectiveFirewallsResponse,
+    NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy,
     NetworksRemovePeeringRequest,
     NetworksUpdatePeeringRequest,
     NodeGroup,
@@ -701,9 +753,11 @@ from .compute import (
     PatchAutoscalerRequest,
     PatchBackendBucketRequest,
     PatchBackendServiceRequest,
+    PatchFirewallPolicyRequest,
     PatchFirewallRequest,
     PatchForwardingRuleRequest,
     PatchGlobalForwardingRuleRequest,
+    PatchGlobalPublicDelegatedPrefixeRequest,
     PatchHealthCheckRequest,
     PatchImageRequest,
     PatchInstanceGroupManagerRequest,
@@ -714,6 +768,8 @@ from .compute import (
     PatchPacketMirroringRequest,
     PatchPerInstanceConfigsInstanceGroupManagerRequest,
     PatchPerInstanceConfigsRegionInstanceGroupManagerRequest,
+    PatchPublicAdvertisedPrefixeRequest,
+    PatchPublicDelegatedPrefixeRequest,
     PatchRegionAutoscalerRequest,
     PatchRegionBackendServiceRequest,
     PatchRegionHealthCheckRequest,
@@ -721,12 +777,14 @@ from .compute import (
     PatchRegionInstanceGroupManagerRequest,
     PatchRegionUrlMapRequest,
     PatchRouterRequest,
+    PatchRuleFirewallPolicyRequest,
     PatchRuleSecurityPolicyRequest,
     PatchSecurityPolicyRequest,
     PatchSslPolicyRequest,
     PatchSubnetworkRequest,
     PatchTargetGrpcProxyRequest,
     PatchTargetHttpProxyRequest,
+    PatchTargetHttpsProxyRequest,
     PatchUrlMapRequest,
     PathMatcher,
     PathRule,
@@ -742,6 +800,14 @@ from .compute import (
     ProjectsGetXpnResources,
     ProjectsListXpnHostsRequest,
     ProjectsSetDefaultNetworkTierRequest,
+    PublicAdvertisedPrefix,
+    PublicAdvertisedPrefixList,
+    PublicAdvertisedPrefixPublicDelegatedPrefix,
+    PublicDelegatedPrefix,
+    PublicDelegatedPrefixAggregatedList,
+    PublicDelegatedPrefixesScopedList,
+    PublicDelegatedPrefixList,
+    PublicDelegatedPrefixPublicDelegatedSubPrefix,
     Quota,
     RawDisk,
     RecreateInstancesInstanceGroupManagerRequest,
@@ -776,6 +842,7 @@ from .compute import (
     RegionSetPolicyRequest,
     RegionTargetHttpsProxiesSetSslCertificatesRequest,
     RegionUrlMapsValidateRequest,
+    RemoveAssociationFirewallPolicyRequest,
     RemoveHealthCheckTargetPoolRequest,
     RemoveInstancesInstanceGroupRequest,
     RemoveInstanceTargetPoolRequest,
@@ -783,6 +850,7 @@ from .compute import (
     RemoveResourcePoliciesDiskRequest,
     RemoveResourcePoliciesInstanceRequest,
     RemoveResourcePoliciesRegionDiskRequest,
+    RemoveRuleFirewallPolicyRequest,
     RemoveRuleSecurityPolicyRequest,
     RequestMirrorPolicy,
     Reservation,
@@ -805,7 +873,11 @@ from .compute import (
     ResourcePolicyDailyCycle,
     ResourcePolicyGroupPlacementPolicy,
     ResourcePolicyHourlyCycle,
+    ResourcePolicyInstanceSchedulePolicy,
+    ResourcePolicyInstanceSchedulePolicySchedule,
     ResourcePolicyList,
+    ResourcePolicyResourceStatus,
+    ResourcePolicyResourceStatusInstanceSchedulePolicyStatus,
     ResourcePolicySnapshotSchedulePolicy,
     ResourcePolicySnapshotSchedulePolicyRetentionPolicy,
     ResourcePolicySnapshotSchedulePolicySchedule,
@@ -831,6 +903,7 @@ from .compute import (
     RouterStatusNatStatus,
     RouterStatusResponse,
     Rule,
+    ScalingScheduleStatus,
     Scheduling,
     SchedulingNodeAffinity,
     ScratchDisks,
@@ -855,6 +928,7 @@ from .compute import (
     SetDeletionProtectionInstanceRequest,
     SetDiskAutoDeleteInstanceRequest,
     SetIamPolicyDiskRequest,
+    SetIamPolicyFirewallPolicyRequest,
     SetIamPolicyImageRequest,
     SetIamPolicyInstanceRequest,
     SetIamPolicyInstanceTemplateRequest,
@@ -870,6 +944,8 @@ from .compute import (
     SetInstanceTemplateRegionInstanceGroupManagerRequest,
     SetLabelsDiskRequest,
     SetLabelsExternalVpnGatewayRequest,
+    SetLabelsForwardingRuleRequest,
+    SetLabelsGlobalForwardingRuleRequest,
     SetLabelsImageRequest,
     SetLabelsInstanceRequest,
     SetLabelsRegionDiskRequest,
@@ -984,6 +1060,7 @@ from .compute import (
     TestFailure,
     TestIamPermissionsDiskRequest,
     TestIamPermissionsExternalVpnGatewayRequest,
+    TestIamPermissionsFirewallPolicyRequest,
     TestIamPermissionsImageRequest,
     TestIamPermissionsInstanceRequest,
     TestIamPermissionsInstanceTemplateRequest,
@@ -1028,6 +1105,7 @@ from .compute import (
     UrlMapsValidateRequest,
     UrlMapsValidateResponse,
     UrlMapTest,
+    UrlMapTestHeader,
     UrlMapValidationResult,
     UrlRewrite,
     UsableSubnetwork,
@@ -1080,6 +1158,7 @@ __all__ = (
     "AcceleratorTypesScopedList",
     "AccessConfig",
     "AddAccessConfigInstanceRequest",
+    "AddAssociationFirewallPolicyRequest",
     "AddHealthCheckTargetPoolRequest",
     "AddInstancesInstanceGroupRequest",
     "AddInstanceTargetPoolRequest",
@@ -1092,9 +1171,11 @@ __all__ = (
     "AddressAggregatedList",
     "AddressesScopedList",
     "AddressList",
+    "AddRuleFirewallPolicyRequest",
     "AddRuleSecurityPolicyRequest",
     "AddSignedUrlKeyBackendBucketRequest",
     "AddSignedUrlKeyBackendServiceRequest",
+    "AdvancedMachineFeatures",
     "AggregatedListAcceleratorTypesRequest",
     "AggregatedListAddressesRequest",
     "AggregatedListAutoscalersRequest",
@@ -1114,6 +1195,7 @@ __all__ = (
     "AggregatedListNodeTemplatesRequest",
     "AggregatedListNodeTypesRequest",
     "AggregatedListPacketMirroringsRequest",
+    "AggregatedListPublicDelegatedPrefixesRequest",
     "AggregatedListRegionCommitmentsRequest",
     "AggregatedListReservationsRequest",
     "AggregatedListResourcePoliciesRequest",
@@ -1153,13 +1235,18 @@ __all__ = (
     "AutoscalingPolicyCustomMetricUtilization",
     "AutoscalingPolicyLoadBalancingUtilization",
     "AutoscalingPolicyScaleInControl",
+    "AutoscalingPolicyScalingSchedule",
     "Backend",
     "BackendBucket",
     "BackendBucketCdnPolicy",
+    "BackendBucketCdnPolicyBypassCacheOnRequestHeader",
+    "BackendBucketCdnPolicyNegativeCachingPolicy",
     "BackendBucketList",
     "BackendService",
     "BackendServiceAggregatedList",
     "BackendServiceCdnPolicy",
+    "BackendServiceCdnPolicyBypassCacheOnRequestHeader",
+    "BackendServiceCdnPolicyNegativeCachingPolicy",
     "BackendServiceFailoverPolicy",
     "BackendServiceGroupHealth",
     "BackendServiceIAP",
@@ -1168,9 +1255,14 @@ __all__ = (
     "BackendServiceReference",
     "BackendServicesScopedList",
     "Binding",
+    "BulkInsertInstanceRequest",
+    "BulkInsertInstanceResource",
+    "BulkInsertInstanceResourcePerInstanceProperties",
+    "BulkInsertRegionInstanceRequest",
     "CacheInvalidationRule",
     "CacheKeyPolicy",
     "CircuitBreakers",
+    "CloneRulesFirewallPolicyRequest",
     "Commitment",
     "CommitmentAggregatedList",
     "CommitmentList",
@@ -1195,6 +1287,7 @@ __all__ = (
     "DeleteBackendServiceRequest",
     "DeleteDiskRequest",
     "DeleteExternalVpnGatewayRequest",
+    "DeleteFirewallPolicyRequest",
     "DeleteFirewallRequest",
     "DeleteForwardingRuleRequest",
     "DeleteGlobalAddressRequest",
@@ -1204,6 +1297,7 @@ __all__ = (
     "DeleteGlobalOperationResponse",
     "DeleteGlobalOrganizationOperationRequest",
     "DeleteGlobalOrganizationOperationResponse",
+    "DeleteGlobalPublicDelegatedPrefixeRequest",
     "DeleteHealthCheckRequest",
     "DeleteImageRequest",
     "DeleteInstanceGroupManagerRequest",
@@ -1223,6 +1317,8 @@ __all__ = (
     "DeletePacketMirroringRequest",
     "DeletePerInstanceConfigsInstanceGroupManagerRequest",
     "DeletePerInstanceConfigsRegionInstanceGroupManagerRequest",
+    "DeletePublicAdvertisedPrefixeRequest",
+    "DeletePublicDelegatedPrefixeRequest",
     "DeleteRegionAutoscalerRequest",
     "DeleteRegionBackendServiceRequest",
     "DeleteRegionDiskRequest",
@@ -1301,21 +1397,33 @@ __all__ = (
     "Firewall",
     "FirewallList",
     "FirewallLogConfig",
+    "FirewallPoliciesListAssociationsResponse",
+    "FirewallPolicy",
+    "FirewallPolicyAssociation",
+    "FirewallPolicyList",
+    "FirewallPolicyRule",
+    "FirewallPolicyRuleMatcher",
+    "FirewallPolicyRuleMatcherLayer4Config",
     "FixedOrPercent",
     "ForwardingRule",
     "ForwardingRuleAggregatedList",
     "ForwardingRuleList",
     "ForwardingRuleReference",
+    "ForwardingRuleServiceDirectoryRegistration",
     "ForwardingRulesScopedList",
     "GetAcceleratorTypeRequest",
     "GetAddressRequest",
+    "GetAssociationFirewallPolicyRequest",
     "GetAutoscalerRequest",
     "GetBackendBucketRequest",
     "GetBackendServiceRequest",
     "GetDiagnosticsInterconnectRequest",
     "GetDiskRequest",
     "GetDiskTypeRequest",
+    "GetEffectiveFirewallsInstanceRequest",
+    "GetEffectiveFirewallsNetworkRequest",
     "GetExternalVpnGatewayRequest",
+    "GetFirewallPolicyRequest",
     "GetFirewallRequest",
     "GetForwardingRuleRequest",
     "GetFromFamilyImageRequest",
@@ -1324,12 +1432,14 @@ __all__ = (
     "GetGlobalNetworkEndpointGroupRequest",
     "GetGlobalOperationRequest",
     "GetGlobalOrganizationOperationRequest",
+    "GetGlobalPublicDelegatedPrefixeRequest",
     "GetGuestAttributesInstanceRequest",
     "GetHealthBackendServiceRequest",
     "GetHealthCheckRequest",
     "GetHealthRegionBackendServiceRequest",
     "GetHealthTargetPoolRequest",
     "GetIamPolicyDiskRequest",
+    "GetIamPolicyFirewallPolicyRequest",
     "GetIamPolicyImageRequest",
     "GetIamPolicyInstanceRequest",
     "GetIamPolicyInstanceTemplateRequest",
@@ -1360,6 +1470,8 @@ __all__ = (
     "GetNodeTypeRequest",
     "GetPacketMirroringRequest",
     "GetProjectRequest",
+    "GetPublicAdvertisedPrefixeRequest",
+    "GetPublicDelegatedPrefixeRequest",
     "GetRegionAutoscalerRequest",
     "GetRegionBackendServiceRequest",
     "GetRegionCommitmentRequest",
@@ -1382,6 +1494,7 @@ __all__ = (
     "GetRouteRequest",
     "GetRouterRequest",
     "GetRouterStatusRouterRequest",
+    "GetRuleFirewallPolicyRequest",
     "GetRuleSecurityPolicyRequest",
     "GetScreenshotInstanceRequest",
     "GetSecurityPolicyRequest",
@@ -1409,6 +1522,7 @@ __all__ = (
     "GetZoneRequest",
     "GlobalNetworkEndpointGroupsAttachEndpointsRequest",
     "GlobalNetworkEndpointGroupsDetachEndpointsRequest",
+    "GlobalOrganizationSetPolicyRequest",
     "GlobalSetLabelsRequest",
     "GlobalSetPolicyRequest",
     "GRPCHealthCheck",
@@ -1452,11 +1566,13 @@ __all__ = (
     "InsertBackendServiceRequest",
     "InsertDiskRequest",
     "InsertExternalVpnGatewayRequest",
+    "InsertFirewallPolicyRequest",
     "InsertFirewallRequest",
     "InsertForwardingRuleRequest",
     "InsertGlobalAddressRequest",
     "InsertGlobalForwardingRuleRequest",
     "InsertGlobalNetworkEndpointGroupRequest",
+    "InsertGlobalPublicDelegatedPrefixeRequest",
     "InsertHealthCheckRequest",
     "InsertImageRequest",
     "InsertInstanceGroupManagerRequest",
@@ -1471,6 +1587,8 @@ __all__ = (
     "InsertNodeGroupRequest",
     "InsertNodeTemplateRequest",
     "InsertPacketMirroringRequest",
+    "InsertPublicAdvertisedPrefixeRequest",
+    "InsertPublicDelegatedPrefixeRequest",
     "InsertRegionAutoscalerRequest",
     "InsertRegionBackendServiceRequest",
     "InsertRegionCommitmentRequest",
@@ -1548,6 +1666,8 @@ __all__ = (
     "InstanceProperties",
     "InstanceReference",
     "InstancesAddResourcePoliciesRequest",
+    "InstancesGetEffectiveFirewallsResponse",
+    "InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy",
     "InstancesRemoveResourcePoliciesRequest",
     "InstancesScopedList",
     "InstancesSetLabelsRequest",
@@ -1589,6 +1709,7 @@ __all__ = (
     "LicensesListResponse",
     "ListAcceleratorTypesRequest",
     "ListAddressesRequest",
+    "ListAssociationsFirewallPolicyRequest",
     "ListAutoscalersRequest",
     "ListAvailableFeaturesSslPoliciesRequest",
     "ListBackendBucketsRequest",
@@ -1598,6 +1719,7 @@ __all__ = (
     "ListErrorsInstanceGroupManagersRequest",
     "ListErrorsRegionInstanceGroupManagersRequest",
     "ListExternalVpnGatewaysRequest",
+    "ListFirewallPoliciesRequest",
     "ListFirewallsRequest",
     "ListForwardingRulesRequest",
     "ListGlobalAddressesRequest",
@@ -1605,6 +1727,7 @@ __all__ = (
     "ListGlobalNetworkEndpointGroupsRequest",
     "ListGlobalOperationsRequest",
     "ListGlobalOrganizationOperationsRequest",
+    "ListGlobalPublicDelegatedPrefixesRequest",
     "ListHealthChecksRequest",
     "ListImagesRequest",
     "ListInstanceGroupManagersRequest",
@@ -1633,6 +1756,8 @@ __all__ = (
     "ListPerInstanceConfigsInstanceGroupManagersRequest",
     "ListPerInstanceConfigsRegionInstanceGroupManagersRequest",
     "ListPreconfiguredExpressionSetsSecurityPoliciesRequest",
+    "ListPublicAdvertisedPrefixesRequest",
+    "ListPublicDelegatedPrefixesRequest",
     "ListReferrersInstancesRequest",
     "ListRegionAutoscalersRequest",
     "ListRegionBackendServicesRequest",
@@ -1676,6 +1801,8 @@ __all__ = (
     "ListZoneOperationsRequest",
     "ListZonesRequest",
     "LocalDisk",
+    "LocationPolicy",
+    "LocationPolicyLocation",
     "LogConfig",
     "LogConfigCloudAuditOptions",
     "LogConfigCounterOptions",
@@ -1693,6 +1820,7 @@ __all__ = (
     "MetadataFilter",
     "MetadataFilterLabelMatch",
     "MoveDiskProjectRequest",
+    "MoveFirewallPolicyRequest",
     "MoveInstanceProjectRequest",
     "NamedPort",
     "Network",
@@ -1714,6 +1842,8 @@ __all__ = (
     "NetworkPeering",
     "NetworkRoutingConfig",
     "NetworksAddPeeringRequest",
+    "NetworksGetEffectiveFirewallsResponse",
+    "NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy",
     "NetworksRemovePeeringRequest",
     "NetworksUpdatePeeringRequest",
     "NodeGroup",
@@ -1757,9 +1887,11 @@ __all__ = (
     "PatchAutoscalerRequest",
     "PatchBackendBucketRequest",
     "PatchBackendServiceRequest",
+    "PatchFirewallPolicyRequest",
     "PatchFirewallRequest",
     "PatchForwardingRuleRequest",
     "PatchGlobalForwardingRuleRequest",
+    "PatchGlobalPublicDelegatedPrefixeRequest",
     "PatchHealthCheckRequest",
     "PatchImageRequest",
     "PatchInstanceGroupManagerRequest",
@@ -1770,6 +1902,8 @@ __all__ = (
     "PatchPacketMirroringRequest",
     "PatchPerInstanceConfigsInstanceGroupManagerRequest",
     "PatchPerInstanceConfigsRegionInstanceGroupManagerRequest",
+    "PatchPublicAdvertisedPrefixeRequest",
+    "PatchPublicDelegatedPrefixeRequest",
     "PatchRegionAutoscalerRequest",
     "PatchRegionBackendServiceRequest",
     "PatchRegionHealthCheckRequest",
@@ -1777,12 +1911,14 @@ __all__ = (
     "PatchRegionInstanceGroupManagerRequest",
     "PatchRegionUrlMapRequest",
     "PatchRouterRequest",
+    "PatchRuleFirewallPolicyRequest",
     "PatchRuleSecurityPolicyRequest",
     "PatchSecurityPolicyRequest",
     "PatchSslPolicyRequest",
     "PatchSubnetworkRequest",
     "PatchTargetGrpcProxyRequest",
     "PatchTargetHttpProxyRequest",
+    "PatchTargetHttpsProxyRequest",
     "PatchUrlMapRequest",
     "PathMatcher",
     "PathRule",
@@ -1798,6 +1934,14 @@ __all__ = (
     "ProjectsGetXpnResources",
     "ProjectsListXpnHostsRequest",
     "ProjectsSetDefaultNetworkTierRequest",
+    "PublicAdvertisedPrefix",
+    "PublicAdvertisedPrefixList",
+    "PublicAdvertisedPrefixPublicDelegatedPrefix",
+    "PublicDelegatedPrefix",
+    "PublicDelegatedPrefixAggregatedList",
+    "PublicDelegatedPrefixesScopedList",
+    "PublicDelegatedPrefixList",
+    "PublicDelegatedPrefixPublicDelegatedSubPrefix",
     "Quota",
     "RawDisk",
     "RecreateInstancesInstanceGroupManagerRequest",
@@ -1832,6 +1976,7 @@ __all__ = (
     "RegionSetPolicyRequest",
     "RegionTargetHttpsProxiesSetSslCertificatesRequest",
     "RegionUrlMapsValidateRequest",
+    "RemoveAssociationFirewallPolicyRequest",
     "RemoveHealthCheckTargetPoolRequest",
     "RemoveInstancesInstanceGroupRequest",
     "RemoveInstanceTargetPoolRequest",
@@ -1839,6 +1984,7 @@ __all__ = (
     "RemoveResourcePoliciesDiskRequest",
     "RemoveResourcePoliciesInstanceRequest",
     "RemoveResourcePoliciesRegionDiskRequest",
+    "RemoveRuleFirewallPolicyRequest",
     "RemoveRuleSecurityPolicyRequest",
     "RequestMirrorPolicy",
     "Reservation",
@@ -1861,7 +2007,11 @@ __all__ = (
     "ResourcePolicyDailyCycle",
     "ResourcePolicyGroupPlacementPolicy",
     "ResourcePolicyHourlyCycle",
+    "ResourcePolicyInstanceSchedulePolicy",
+    "ResourcePolicyInstanceSchedulePolicySchedule",
     "ResourcePolicyList",
+    "ResourcePolicyResourceStatus",
+    "ResourcePolicyResourceStatusInstanceSchedulePolicyStatus",
     "ResourcePolicySnapshotSchedulePolicy",
     "ResourcePolicySnapshotSchedulePolicyRetentionPolicy",
     "ResourcePolicySnapshotSchedulePolicySchedule",
@@ -1887,6 +2037,7 @@ __all__ = (
     "RouterStatusNatStatus",
     "RouterStatusResponse",
     "Rule",
+    "ScalingScheduleStatus",
     "Scheduling",
     "SchedulingNodeAffinity",
     "ScratchDisks",
@@ -1911,6 +2062,7 @@ __all__ = (
     "SetDeletionProtectionInstanceRequest",
     "SetDiskAutoDeleteInstanceRequest",
     "SetIamPolicyDiskRequest",
+    "SetIamPolicyFirewallPolicyRequest",
     "SetIamPolicyImageRequest",
     "SetIamPolicyInstanceRequest",
     "SetIamPolicyInstanceTemplateRequest",
@@ -1926,6 +2078,8 @@ __all__ = (
     "SetInstanceTemplateRegionInstanceGroupManagerRequest",
     "SetLabelsDiskRequest",
     "SetLabelsExternalVpnGatewayRequest",
+    "SetLabelsForwardingRuleRequest",
+    "SetLabelsGlobalForwardingRuleRequest",
     "SetLabelsImageRequest",
     "SetLabelsInstanceRequest",
     "SetLabelsRegionDiskRequest",
@@ -2040,6 +2194,7 @@ __all__ = (
     "TestFailure",
     "TestIamPermissionsDiskRequest",
     "TestIamPermissionsExternalVpnGatewayRequest",
+    "TestIamPermissionsFirewallPolicyRequest",
     "TestIamPermissionsImageRequest",
     "TestIamPermissionsInstanceRequest",
     "TestIamPermissionsInstanceTemplateRequest",
@@ -2084,6 +2239,7 @@ __all__ = (
     "UrlMapsValidateRequest",
     "UrlMapsValidateResponse",
     "UrlMapTest",
+    "UrlMapTestHeader",
     "UrlMapValidationResult",
     "UrlRewrite",
     "UsableSubnetwork",
