@@ -36,9 +36,6 @@ from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.backend_buckets import BackendBucketsClient
 from google.cloud.compute_v1.services.backend_buckets import pagers
 from google.cloud.compute_v1.services.backend_buckets import transports
-from google.cloud.compute_v1.services.backend_buckets.transports.base import (
-    _API_CORE_VERSION,
-)
 from google.cloud.compute_v1.services.backend_buckets.transports.base import (
     _GOOGLE_AUTH_VERSION,
 )
@@ -47,8 +44,9 @@ from google.oauth2 import service_account
 import google.auth
 
 
-# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
-# - Delete all the api-core and auth "less than" test cases
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
 # - Delete these pytest markers (Make the "greater than or equal to" tests the default).
 requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
     packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
@@ -59,16 +57,6 @@ requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
     reason="This test requires google-auth >= 1.25.0",
 )
 
-requires_api_core_lt_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core < 1.26.0",
-)
-
-requires_api_core_gte_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core >= 1.26.0",
-)
-
 
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
@@ -432,6 +420,7 @@ def test_add_signed_url_key_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -467,6 +456,7 @@ def test_add_signed_url_key_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -565,6 +555,7 @@ def test_delete_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -600,6 +591,7 @@ def test_delete_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -689,6 +681,7 @@ def test_delete_signed_url_key_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -724,6 +717,7 @@ def test_delete_signed_url_key_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -808,7 +802,11 @@ def test_get_rest(
         return_value = compute.BackendBucket(
             bucket_name="bucket_name_value",
             cdn_policy=compute.BackendBucketCdnPolicy(
-                cache_mode=compute.BackendBucketCdnPolicy.CacheMode.CACHE_ALL_STATIC
+                bypass_cache_on_request_headers=[
+                    compute.BackendBucketCdnPolicyBypassCacheOnRequestHeader(
+                        header_name="header_name_value"
+                    )
+                ]
             ),
             creation_timestamp="creation_timestamp_value",
             custom_response_headers=["custom_response_headers_value"],
@@ -832,7 +830,11 @@ def test_get_rest(
     assert isinstance(response, compute.BackendBucket)
     assert response.bucket_name == "bucket_name_value"
     assert response.cdn_policy == compute.BackendBucketCdnPolicy(
-        cache_mode=compute.BackendBucketCdnPolicy.CacheMode.CACHE_ALL_STATIC
+        bypass_cache_on_request_headers=[
+            compute.BackendBucketCdnPolicyBypassCacheOnRequestHeader(
+                header_name="header_name_value"
+            )
+        ]
     )
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.custom_response_headers == ["custom_response_headers_value"]
@@ -917,6 +919,7 @@ def test_insert_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -952,6 +955,7 @@ def test_insert_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -1179,6 +1183,7 @@ def test_patch_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1214,6 +1219,7 @@ def test_patch_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -1314,6 +1320,7 @@ def test_update_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1349,6 +1356,7 @@ def test_update_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
