@@ -36,9 +36,6 @@ from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.instance_templates import InstanceTemplatesClient
 from google.cloud.compute_v1.services.instance_templates import pagers
 from google.cloud.compute_v1.services.instance_templates import transports
-from google.cloud.compute_v1.services.instance_templates.transports.base import (
-    _API_CORE_VERSION,
-)
 from google.cloud.compute_v1.services.instance_templates.transports.base import (
     _GOOGLE_AUTH_VERSION,
 )
@@ -47,8 +44,9 @@ from google.oauth2 import service_account
 import google.auth
 
 
-# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
-# - Delete all the api-core and auth "less than" test cases
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
 # - Delete these pytest markers (Make the "greater than or equal to" tests the default).
 requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
     packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
@@ -59,16 +57,6 @@ requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
     reason="This test requires google-auth >= 1.25.0",
 )
 
-requires_api_core_lt_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core < 1.26.0",
-)
-
-requires_api_core_gte_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core >= 1.26.0",
-)
-
 
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
@@ -443,6 +431,7 @@ def test_delete_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -478,6 +467,7 @@ def test_delete_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -561,7 +551,11 @@ def test_get_rest(
             id="id_value",
             kind="kind_value",
             name="name_value",
-            properties=compute.InstanceProperties(can_ip_forward=True),
+            properties=compute.InstanceProperties(
+                advanced_machine_features=compute.AdvancedMachineFeatures(
+                    enable_nested_virtualization=True
+                )
+            ),
             self_link="self_link_value",
             source_instance="source_instance_value",
             source_instance_params=compute.SourceInstanceParams(
@@ -584,7 +578,11 @@ def test_get_rest(
     assert response.id == "id_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
-    assert response.properties == compute.InstanceProperties(can_ip_forward=True)
+    assert response.properties == compute.InstanceProperties(
+        advanced_machine_features=compute.AdvancedMachineFeatures(
+            enable_nested_virtualization=True
+        )
+    )
     assert response.self_link == "self_link_value"
     assert response.source_instance == "source_instance_value"
     assert response.source_instance_params == compute.SourceInstanceParams(
@@ -767,6 +765,7 @@ def test_insert_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -802,6 +801,7 @@ def test_insert_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
