@@ -38,9 +38,6 @@ from google.cloud.compute_v1.services.interconnect_attachments import (
 )
 from google.cloud.compute_v1.services.interconnect_attachments import pagers
 from google.cloud.compute_v1.services.interconnect_attachments import transports
-from google.cloud.compute_v1.services.interconnect_attachments.transports.base import (
-    _API_CORE_VERSION,
-)
 from google.cloud.compute_v1.services.interconnect_attachments.transports.base import (
     _GOOGLE_AUTH_VERSION,
 )
@@ -49,8 +46,9 @@ from google.oauth2 import service_account
 import google.auth
 
 
-# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
-# - Delete all the api-core and auth "less than" test cases
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
 # - Delete these pytest markers (Make the "greater than or equal to" tests the default).
 requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
     packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
@@ -61,16 +59,6 @@ requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
     reason="This test requires google-auth >= 1.25.0",
 )
 
-requires_api_core_lt_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core < 1.26.0",
-)
-
-requires_api_core_gte_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core >= 1.26.0",
-)
-
 
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
@@ -640,6 +628,7 @@ def test_delete_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -675,6 +664,7 @@ def test_delete_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -770,9 +760,11 @@ def test_get_rest(
             dataplane_version=1807,
             description="description_value",
             edge_availability_domain=compute.InterconnectAttachment.EdgeAvailabilityDomain.AVAILABILITY_DOMAIN_1,
+            encryption=compute.InterconnectAttachment.Encryption.IPSEC,
             google_reference_id="google_reference_id_value",
             id="id_value",
             interconnect="interconnect_value",
+            ipsec_internal_addresses=["ipsec_internal_addresses_value"],
             kind="kind_value",
             mtu=342,
             name="name_value",
@@ -815,9 +807,11 @@ def test_get_rest(
         response.edge_availability_domain
         == compute.InterconnectAttachment.EdgeAvailabilityDomain.AVAILABILITY_DOMAIN_1
     )
+    assert response.encryption == compute.InterconnectAttachment.Encryption.IPSEC
     assert response.google_reference_id == "google_reference_id_value"
     assert response.id == "id_value"
     assert response.interconnect == "interconnect_value"
+    assert response.ipsec_internal_addresses == ["ipsec_internal_addresses_value"]
     assert response.kind == "kind_value"
     assert response.mtu == 342
     assert response.name == "name_value"
@@ -923,6 +917,7 @@ def test_insert_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -958,6 +953,7 @@ def test_insert_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -1211,6 +1207,7 @@ def test_patch_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1246,6 +1243,7 @@ def test_patch_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
