@@ -38,9 +38,6 @@ from google.cloud.compute_v1.services.network_endpoint_groups import (
 )
 from google.cloud.compute_v1.services.network_endpoint_groups import pagers
 from google.cloud.compute_v1.services.network_endpoint_groups import transports
-from google.cloud.compute_v1.services.network_endpoint_groups.transports.base import (
-    _API_CORE_VERSION,
-)
 from google.cloud.compute_v1.services.network_endpoint_groups.transports.base import (
     _GOOGLE_AUTH_VERSION,
 )
@@ -49,8 +46,9 @@ from google.oauth2 import service_account
 import google.auth
 
 
-# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
-# - Delete all the api-core and auth "less than" test cases
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
 # - Delete these pytest markers (Make the "greater than or equal to" tests the default).
 requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
     packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
@@ -61,16 +59,6 @@ requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
     reason="This test requires google-auth >= 1.25.0",
 )
 
-requires_api_core_lt_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core < 1.26.0",
-)
-
-requires_api_core_gte_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core >= 1.26.0",
-)
-
 
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
@@ -643,6 +631,7 @@ def test_attach_network_endpoints_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -678,6 +667,7 @@ def test_attach_network_endpoints_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -791,6 +781,7 @@ def test_delete_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -826,6 +817,7 @@ def test_delete_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -924,6 +916,7 @@ def test_detach_network_endpoints_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -959,6 +952,7 @@ def test_detach_network_endpoints_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -1074,7 +1068,7 @@ def test_get_rest(
             kind="kind_value",
             name="name_value",
             network="network_value",
-            network_endpoint_type=compute.NetworkEndpointGroup.NetworkEndpointType.GCE_VM_IP_PORT,
+            network_endpoint_type=compute.NetworkEndpointGroup.NetworkEndpointType.GCE_VM_IP,
             region="region_value",
             self_link="self_link_value",
             size=443,
@@ -1111,7 +1105,7 @@ def test_get_rest(
     assert response.network == "network_value"
     assert (
         response.network_endpoint_type
-        == compute.NetworkEndpointGroup.NetworkEndpointType.GCE_VM_IP_PORT
+        == compute.NetworkEndpointGroup.NetworkEndpointType.GCE_VM_IP
     )
     assert response.region == "region_value"
     assert response.self_link == "self_link_value"
@@ -1201,6 +1195,7 @@ def test_insert_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1236,6 +1231,7 @@ def test_insert_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
