@@ -36,9 +36,6 @@ from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.region_autoscalers import RegionAutoscalersClient
 from google.cloud.compute_v1.services.region_autoscalers import pagers
 from google.cloud.compute_v1.services.region_autoscalers import transports
-from google.cloud.compute_v1.services.region_autoscalers.transports.base import (
-    _API_CORE_VERSION,
-)
 from google.cloud.compute_v1.services.region_autoscalers.transports.base import (
     _GOOGLE_AUTH_VERSION,
 )
@@ -47,8 +44,9 @@ from google.oauth2 import service_account
 import google.auth
 
 
-# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
-# - Delete all the api-core and auth "less than" test cases
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
 # - Delete these pytest markers (Make the "greater than or equal to" tests the default).
 requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
     packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
@@ -59,16 +57,6 @@ requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
     reason="This test requires google-auth >= 1.25.0",
 )
 
-requires_api_core_lt_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core < 1.26.0",
-)
-
-requires_api_core_gte_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core >= 1.26.0",
-)
-
 
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
@@ -443,6 +431,7 @@ def test_delete_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -478,6 +467,7 @@ def test_delete_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -568,6 +558,11 @@ def test_get_rest(
             name="name_value",
             recommended_size=1693,
             region="region_value",
+            scaling_schedule_status={
+                "key_value": compute.ScalingScheduleStatus(
+                    last_start_time="last_start_time_value"
+                )
+            },
             self_link="self_link_value",
             status=compute.Autoscaler.Status.ACTIVE,
             status_details=[compute.AutoscalerStatusDetails(message="message_value")],
@@ -595,6 +590,11 @@ def test_get_rest(
     assert response.name == "name_value"
     assert response.recommended_size == 1693
     assert response.region == "region_value"
+    assert response.scaling_schedule_status == {
+        "key_value": compute.ScalingScheduleStatus(
+            last_start_time="last_start_time_value"
+        )
+    }
     assert response.self_link == "self_link_value"
     assert response.status == compute.Autoscaler.Status.ACTIVE
     assert response.status_details == [
@@ -681,6 +681,7 @@ def test_insert_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -716,6 +717,7 @@ def test_insert_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -964,6 +966,7 @@ def test_patch_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -999,6 +1002,7 @@ def test_patch_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -1101,6 +1105,7 @@ def test_update_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1136,6 +1141,7 @@ def test_update_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
