@@ -36,9 +36,6 @@ from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.region_disks import RegionDisksClient
 from google.cloud.compute_v1.services.region_disks import pagers
 from google.cloud.compute_v1.services.region_disks import transports
-from google.cloud.compute_v1.services.region_disks.transports.base import (
-    _API_CORE_VERSION,
-)
 from google.cloud.compute_v1.services.region_disks.transports.base import (
     _GOOGLE_AUTH_VERSION,
 )
@@ -47,8 +44,9 @@ from google.oauth2 import service_account
 import google.auth
 
 
-# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
-# - Delete all the api-core and auth "less than" test cases
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
 # - Delete these pytest markers (Make the "greater than or equal to" tests the default).
 requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
     packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
@@ -59,16 +57,6 @@ requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
     reason="This test requires google-auth >= 1.25.0",
 )
 
-requires_api_core_lt_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core < 1.26.0",
-)
-
-requires_api_core_gte_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core >= 1.26.0",
-)
-
 
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
@@ -425,6 +413,7 @@ def test_add_resource_policies_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -460,6 +449,7 @@ def test_add_resource_policies_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -565,6 +555,7 @@ def test_create_snapshot_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -600,6 +591,7 @@ def test_create_snapshot_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -701,6 +693,7 @@ def test_delete_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -736,6 +729,7 @@ def test_delete_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -832,12 +826,15 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRegionDiskReq
             last_detach_timestamp="last_detach_timestamp_value",
             license_codes=["license_codes_value"],
             licenses=["licenses_value"],
+            location_hint="location_hint_value",
             name="name_value",
             options="options_value",
             physical_block_size_bytes="physical_block_size_bytes_value",
+            provisioned_iops="provisioned_iops_value",
             region="region_value",
             replica_zones=["replica_zones_value"],
             resource_policies=["resource_policies_value"],
+            satisfies_pzs=True,
             self_link="self_link_value",
             size_gb="size_gb_value",
             source_disk="source_disk_value",
@@ -852,6 +849,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRegionDiskReq
                 kms_key_name="kms_key_name_value"
             ),
             source_snapshot_id="source_snapshot_id_value",
+            source_storage_object="source_storage_object_value",
             status=compute.Disk.Status.CREATING,
             type_="type__value",
             users=["users_value"],
@@ -886,12 +884,15 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRegionDiskReq
     assert response.last_detach_timestamp == "last_detach_timestamp_value"
     assert response.license_codes == ["license_codes_value"]
     assert response.licenses == ["licenses_value"]
+    assert response.location_hint == "location_hint_value"
     assert response.name == "name_value"
     assert response.options == "options_value"
     assert response.physical_block_size_bytes == "physical_block_size_bytes_value"
+    assert response.provisioned_iops == "provisioned_iops_value"
     assert response.region == "region_value"
     assert response.replica_zones == ["replica_zones_value"]
     assert response.resource_policies == ["resource_policies_value"]
+    assert response.satisfies_pzs is True
     assert response.self_link == "self_link_value"
     assert response.size_gb == "size_gb_value"
     assert response.source_disk == "source_disk_value"
@@ -906,6 +907,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRegionDiskReq
         kms_key_name="kms_key_name_value"
     )
     assert response.source_snapshot_id == "source_snapshot_id_value"
+    assert response.source_storage_object == "source_storage_object_value"
     assert response.status == compute.Disk.Status.CREATING
     assert response.type_ == "type__value"
     assert response.users == ["users_value"]
@@ -1091,6 +1093,7 @@ def test_insert_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1126,6 +1129,7 @@ def test_insert_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -1353,6 +1357,7 @@ def test_remove_resource_policies_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1388,6 +1393,7 @@ def test_remove_resource_policies_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -1493,6 +1499,7 @@ def test_resize_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1528,6 +1535,7 @@ def test_resize_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -1751,6 +1759,7 @@ def test_set_labels_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1786,6 +1795,7 @@ def test_set_labels_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
