@@ -36,7 +36,6 @@ from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.regions import RegionsClient
 from google.cloud.compute_v1.services.regions import pagers
 from google.cloud.compute_v1.services.regions import transports
-from google.cloud.compute_v1.services.regions.transports.base import _API_CORE_VERSION
 from google.cloud.compute_v1.services.regions.transports.base import (
     _GOOGLE_AUTH_VERSION,
 )
@@ -45,8 +44,9 @@ from google.oauth2 import service_account
 import google.auth
 
 
-# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
-# - Delete all the api-core and auth "less than" test cases
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
 # - Delete these pytest markers (Make the "greater than or equal to" tests the default).
 requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
     packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
@@ -57,16 +57,6 @@ requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
     reason="This test requires google-auth >= 1.25.0",
 )
 
-requires_api_core_lt_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core < 1.26.0",
-)
-
-requires_api_core_gte_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core >= 1.26.0",
-)
-
 
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
@@ -414,6 +404,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRegionRequest
             quotas=[compute.Quota(limit=0.543)],
             self_link="self_link_value",
             status=compute.Region.Status.DOWN,
+            supports_pzs=True,
             zones=["zones_value"],
         )
 
@@ -436,6 +427,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRegionRequest
     assert response.quotas == [compute.Quota(limit=0.543)]
     assert response.self_link == "self_link_value"
     assert response.status == compute.Region.Status.DOWN
+    assert response.supports_pzs is True
     assert response.zones == ["zones_value"]
 
 
