@@ -36,9 +36,6 @@ from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.resource_policies import ResourcePoliciesClient
 from google.cloud.compute_v1.services.resource_policies import pagers
 from google.cloud.compute_v1.services.resource_policies import transports
-from google.cloud.compute_v1.services.resource_policies.transports.base import (
-    _API_CORE_VERSION,
-)
 from google.cloud.compute_v1.services.resource_policies.transports.base import (
     _GOOGLE_AUTH_VERSION,
 )
@@ -47,8 +44,9 @@ from google.oauth2 import service_account
 import google.auth
 
 
-# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
-# - Delete all the api-core and auth "less than" test cases
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
 # - Delete these pytest markers (Make the "greater than or equal to" tests the default).
 requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
     packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
@@ -59,16 +57,6 @@ requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
     reason="This test requires google-auth >= 1.25.0",
 )
 
-requires_api_core_lt_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core < 1.26.0",
-)
-
-requires_api_core_gte_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core >= 1.26.0",
-)
-
 
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
@@ -610,6 +598,7 @@ def test_delete_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -645,6 +634,7 @@ def test_delete_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -733,9 +723,17 @@ def test_get_rest(
                 availability_domain_count=2650
             ),
             id="id_value",
+            instance_schedule_policy=compute.ResourcePolicyInstanceSchedulePolicy(
+                expiration_time="expiration_time_value"
+            ),
             kind="kind_value",
             name="name_value",
             region="region_value",
+            resource_status=compute.ResourcePolicyResourceStatus(
+                instance_schedule_policy=compute.ResourcePolicyResourceStatusInstanceSchedulePolicyStatus(
+                    last_run_start_time="last_run_start_time_value"
+                )
+            ),
             self_link="self_link_value",
             snapshot_schedule_policy=compute.ResourcePolicySnapshotSchedulePolicy(
                 retention_policy=compute.ResourcePolicySnapshotSchedulePolicyRetentionPolicy(
@@ -762,9 +760,20 @@ def test_get_rest(
         == compute.ResourcePolicyGroupPlacementPolicy(availability_domain_count=2650)
     )
     assert response.id == "id_value"
+    assert (
+        response.instance_schedule_policy
+        == compute.ResourcePolicyInstanceSchedulePolicy(
+            expiration_time="expiration_time_value"
+        )
+    )
     assert response.kind == "kind_value"
     assert response.name == "name_value"
     assert response.region == "region_value"
+    assert response.resource_status == compute.ResourcePolicyResourceStatus(
+        instance_schedule_policy=compute.ResourcePolicyResourceStatusInstanceSchedulePolicyStatus(
+            last_run_start_time="last_run_start_time_value"
+        )
+    )
     assert response.self_link == "self_link_value"
     assert (
         response.snapshot_schedule_policy
@@ -958,6 +967,7 @@ def test_insert_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -993,6 +1003,7 @@ def test_insert_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
