@@ -36,7 +36,6 @@ from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.routers import RoutersClient
 from google.cloud.compute_v1.services.routers import pagers
 from google.cloud.compute_v1.services.routers import transports
-from google.cloud.compute_v1.services.routers.transports.base import _API_CORE_VERSION
 from google.cloud.compute_v1.services.routers.transports.base import (
     _GOOGLE_AUTH_VERSION,
 )
@@ -45,8 +44,9 @@ from google.oauth2 import service_account
 import google.auth
 
 
-# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
-# - Delete all the api-core and auth "less than" test cases
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
 # - Delete these pytest markers (Make the "greater than or equal to" tests the default).
 requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
     packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
@@ -57,16 +57,6 @@ requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
     reason="This test requires google-auth >= 1.25.0",
 )
 
-requires_api_core_lt_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core < 1.26.0",
-)
-
-requires_api_core_gte_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core >= 1.26.0",
-)
-
 
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
@@ -581,6 +571,7 @@ def test_delete_rest(transport: str = "rest", request_type=compute.DeleteRouterR
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -616,6 +607,7 @@ def test_delete_rest(transport: str = "rest", request_type=compute.DeleteRouterR
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -704,6 +696,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRouterRequest
             ],
             creation_timestamp="creation_timestamp_value",
             description="description_value",
+            encrypted_interconnect_router=True,
             id="id_value",
             interfaces=[compute.RouterInterface(ip_range="ip_range_value")],
             kind="kind_value",
@@ -732,6 +725,7 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetRouterRequest
     ]
     assert response.creation_timestamp == "creation_timestamp_value"
     assert response.description == "description_value"
+    assert response.encrypted_interconnect_router is True
     assert response.id == "id_value"
     assert response.interfaces == [compute.RouterInterface(ip_range="ip_range_value")]
     assert response.kind == "kind_value"
@@ -1046,6 +1040,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouterR
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1081,6 +1076,7 @@ def test_insert_rest(transport: str = "rest", request_type=compute.InsertRouterR
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -1319,6 +1315,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchRouterReq
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1354,6 +1351,7 @@ def test_patch_rest(transport: str = "rest", request_type=compute.PatchRouterReq
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -1561,6 +1559,7 @@ def test_update_rest(transport: str = "rest", request_type=compute.UpdateRouterR
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1596,6 +1595,7 @@ def test_update_rest(transport: str = "rest", request_type=compute.UpdateRouterR
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
