@@ -36,7 +36,6 @@ from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.compute_v1.services.snapshots import SnapshotsClient
 from google.cloud.compute_v1.services.snapshots import pagers
 from google.cloud.compute_v1.services.snapshots import transports
-from google.cloud.compute_v1.services.snapshots.transports.base import _API_CORE_VERSION
 from google.cloud.compute_v1.services.snapshots.transports.base import (
     _GOOGLE_AUTH_VERSION,
 )
@@ -45,8 +44,9 @@ from google.oauth2 import service_account
 import google.auth
 
 
-# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
-# - Delete all the api-core and auth "less than" test cases
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
 # - Delete these pytest markers (Make the "greater than or equal to" tests the default).
 requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
     packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
@@ -57,16 +57,6 @@ requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
     reason="This test requires google-auth >= 1.25.0",
 )
 
-requires_api_core_lt_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core < 1.26.0",
-)
-
-requires_api_core_gte_1_26_0 = pytest.mark.skipif(
-    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
-    reason="This test requires google-api-core >= 1.26.0",
-)
-
 
 def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
@@ -419,6 +409,7 @@ def test_delete_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -454,6 +445,7 @@ def test_delete_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
@@ -542,7 +534,9 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetSnapshotReque
             labels={"key_value": "value_value"},
             license_codes=["license_codes_value"],
             licenses=["licenses_value"],
+            location_hint="location_hint_value",
             name="name_value",
+            satisfies_pzs=True,
             self_link="self_link_value",
             snapshot_encryption_key=compute.CustomerEncryptionKey(
                 kms_key_name="kms_key_name_value"
@@ -580,7 +574,9 @@ def test_get_rest(transport: str = "rest", request_type=compute.GetSnapshotReque
     assert response.labels == {"key_value": "value_value"}
     assert response.license_codes == ["license_codes_value"]
     assert response.licenses == ["licenses_value"]
+    assert response.location_hint == "location_hint_value"
     assert response.name == "name_value"
+    assert response.satisfies_pzs is True
     assert response.self_link == "self_link_value"
     assert response.snapshot_encryption_key == compute.CustomerEncryptionKey(
         kms_key_name="kms_key_name_value"
@@ -1007,6 +1003,7 @@ def test_set_labels_rest(
             insert_time="insert_time_value",
             kind="kind_value",
             name="name_value",
+            operation_group_id="operation_group_id_value",
             operation_type="operation_type_value",
             progress=885,
             region="region_value",
@@ -1042,6 +1039,7 @@ def test_set_labels_rest(
     assert response.insert_time == "insert_time_value"
     assert response.kind == "kind_value"
     assert response.name == "name_value"
+    assert response.operation_group_id == "operation_group_id_value"
     assert response.operation_type == "operation_type_value"
     assert response.progress == 885
     assert response.region == "region_value"
